@@ -11,7 +11,7 @@ use Carp;
 use vars qw($VERSION);
 use locale;
 
-$VERSION = "1.54";
+$VERSION = "1.55";
 sub Version { $VERSION }
 
 #
@@ -22,6 +22,9 @@ sub _extract_name
 {
     local $_ = shift || '';
     
+    # Bug in unicode \U, perl 5.8.0 breaks when casing utf8 in regex
+    utf8::downgrade($_) if $] eq 5.008;
+
     # trim whitespace
     s/^\s+//;
     s/\s+$//;
